@@ -19,7 +19,7 @@ def clip_gradient(grad, k):
 
     # Compute the threshold
     #print(f"grad: {grad}, k: {k}, grad.size(1): {grad.size(1)}, int(grad.size(1) * (1 - k))): {int(grad.size(1) * (1 - k))}")
-    threshold = torch.kthvalue(torch.abs(grad), int(grad.size(1) * (1 - k)), dim=1)[0]
+    threshold = torch.kthvalue(torch.abs(grad), int(grad.size(1) * k), dim=1)[0]
 
     # Clip the gradients
     clipped_grad = torch.clamp(torch.abs(grad), max=threshold.unsqueeze(1))
